@@ -1,10 +1,10 @@
 from simpleicons.icon import Icon
-icon= Icon(
+roblox_icon= Icon(
     title="Roblox",
     slug="roblox",
     hex="000000",
     source="https://corp.roblox.com/press-kit/",
-    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Roblox icon</title><path d="m13.383 14.341-3.726-.958.959-3.726 3.726.959-.96 3.726zM4.913 0 0 19.088 19.088 24 24 4.912 4.912 0z"/></svg>""",
+    svg="""<svg role="img" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><title>Roblox</title><path d="m13.383 14.341-3.726-.958.959-3.726 3.726.959-.96 3.726zM4.913 0 0 19.088 19.088 24 24 4.912 4.912 0z"/></svg>""",
     guidelines='https://corp.roblox.com/wp-content/uploads/2021/03/Logo_Roblox.zip',
     license=None,
 )
